interceptors

package
v0.0.0-...-4abda61 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 1, 2025 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CommonConnectClientInterceptors

func CommonConnectClientInterceptors(serviceName string, signingKey string) []connect.Interceptor

func CommonConnectInterceptors

func CommonConnectInterceptors(serviceName string, signingKey string, authFunc auth_interceptors.AuthFunc, authOpts ...auth_interceptors.Option) []connect.Interceptor

func ConnectAuthHandler

func ConnectAuthHandler(signingKey string) func(context.Context, string) (context.Context, error)

ConnectAuthHandler is used by a middleware to authenticate requests

func ConnectServerAuthHandler

func ConnectServerAuthHandler(signingKey string) func(context.Context, string) (context.Context, error)

ConnectServerAuthHandler is used by a middleware to authenticate server to server requests

Types

This section is empty.

Directories

Path Synopsis

Jump to